/*
 * Copyright (c) 2012, Jonas Widén (jonas.widen@gmail.com)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "nexa_new.h"

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>

int main(int argc, char **argv)
{
  int opt;
  uint8_t channel = 0;
  uint8_t button = 0;
  nexa_activation_t status = NEXA_ACTIVATION_ON;

  while ((opt = getopt(argc, argv, "c:b:s:")) != -1) {
    switch (opt) {
    case 'c':
      channel = atoi(optarg);
      break;
    case 'b':
      button = atoi(optarg);
      break;
    case 's':
      status = atoi(optarg) ? NEXA_ACTIVATION_ON : NEXA_ACTIVATION_OFF;
      break;
    default: /* '?' */
      fprintf(stderr, "Usage: %s [-c channel] [-b button] [-s status]\n",
	      argv[0]);
      exit(EXIT_FAILURE);
    }
  }

  nexa_new_init();
  
  nexa_new_transmit(channel,
		    button,
		    status,
		    NEXA_DIM_LEVEL_1,
		    false);
  return 0;
}
